/**
 * @file   MKY36.h
 * @author StepTechnica
 * @date   Feb 02, 2023
 * 
 * @brief Evaluation Board 用ヘッダーファイル「MKY36デバイス」
 * 
 * @copyright (C) 2022- StepTechnica Co.,Ltd.
 * 
 * このソフトウェアは、コピー利用、配布、変更の追加、変更を加えたもの再配布、商用利用、有料販売など、どなたも自由にお使いいただくことができます。
 * このソフトウェアには保証はついていません。
 * このソフトウェアを利用したことで問題が起きた際に、ソフトウェアの製作者は一切の責任を負いません。
 * 
 */

#ifndef MKY_36_H
#define MKY_36_H

/* -----------------------------------------------------------------------------
 * #defineマクロ定義
 */
#define MKY_36							//プリプロセッサのデバイス識別用

#define MKY_MEMORY_BASE		0x60000000	//メモリ開始アドレス
#define MKY_MEMORY_SIZE		0x800		//メモリサイズ
#define MAX_ACCESS_SIZE		(0x800)		//コマンドからアクセスできるメモリのサイズ

#define TOP_CtrlArea		0x000		// Control Area
#define TOP_DoArea  		0x080		// Dout Area
#define TOP_DiArea  		0x100		// Din Area
#define TOP_C1Area  		0x180		// C1 Area
#define TOP_C2Area  		0x200		// C2 Area
#define TOP_C3Area  		0x280		// C3 Area
#define TOP_C4Area  		0x300		// C4 Area
#define TOP_C5Area  		0x380		// C1 Area
#define TOP_C6Area  		0x400		// C2 Area
#define TOP_C7Area  		0x480		// C3 Area
#define TOP_DRCArea 		0x500		// DRC Area
#define SZ_AREA     		0x080		//メモリサイズ

#define	OFS_regSCR      	0x0580
#define	OFS_regSSR      	0x0582
#define	OFS_regHPR      	0x0584
#define	OFS_regINT0R    	0x0586
#define	OFS_regINT1R    	0x0588
#define	OFS_regC1CR     	0x058A
#define	OFS_regC2CR     	0x058C
#define	OFS_regBCR      	0x058E
#define	OFS_regCCR      	0x0590



// MKY36_SSR   : 0x0580
#define	BIT_regSSR_ESF  	0x0400
#define	BIT_regSSR_DREQF	0x0200
#define	BIT_regSSR_DRF  	0x0100
#define	BIT_regSSR_SCAN 	0x0080
#define	BIT_regSSR_FT5  	0x0020
#define	BIT_regSSR_FT4  	0x0010
#define	BIT_regSSR_FT3  	0x0008
#define	BIT_regSSR_FT2  	0x0004
#define	BIT_regSSR_FT1  	0x0002
#define	BIT_regSSR_FT0  	0x0001
// MKY36_SCR   : 0x0582
#define	BIT_regSCR_SFS5 	0x2000
#define	BIT_regSCR_SFS4 	0x1000
#define	BIT_regSCR_SFS3 	0x0800
#define	BIT_regSCR_SFS2 	0x0400
#define	BIT_regSCR_SFS1 	0x0200
#define	BIT_regSCR_SFS0 	0x0100
#define	BIT_regSCR_FS5  	0x0020
#define	BIT_regSCR_FS4  	0x0010
#define	BIT_regSCR_FS3  	0x0008
#define	BIT_regSCR_FS2  	0x0004
#define	BIT_regSCR_FS1  	0x0002
#define	BIT_regSCR_FS0  	0x0001
// MKY36_HPR   : 0x0584
#define	BIT_regHPR_WPE  	0x1000
#define	BIT_regHPR_WPA  	0x0100
#define	BIT_regHPR_RPE  	0x0010
// MKY36_INT0R : 0x0586
// MKY36_INT1R : 0x0588
#define	BIT_regINTR_enSSTOP	0x8000
#define	BIT_regINTR_enCHK2 	0x4000
#define	BIT_regINTR_enCHK1 	0x2000
#define	BIT_regINTR_enDREQ 	0x1000
#define	BIT_regINTR_enSCANR	0x0800
#define	BIT_regINTR_enDR2  	0x0400
#define	BIT_regINTR_enDR1  	0x0200
#define	BIT_regINTR_enDR0  	0x0100
#define	BIT_regINTR_SSTOP  	0x0080
#define	BIT_regINTR_CHK2   	0x0040
#define	BIT_regINTR_CHK1   	0x0020
#define	BIT_regINTR_DREQ   	0x0010
#define	BIT_regINTR_SCANR  	0x0008
#define	BIT_regINTR_DR2    	0x0004
#define	BIT_regINTR_DR1    	0x0002
#define	BIT_regINTR_DR0    	0x0001
// MKY36_C1CR  : 0x058A
// MKY36_C2CR  : 0x058C
// MKY36_BCR   : 0x058E
#define	BIT_regBCR_LF2  	0x0400
#define	BIT_regBCR_LF1  	0x0200
#define	BIT_regBCR_LF0  	0x0100
#define	BIT_regBCR_FH   	0x0010
#define	BIT_regBCR_BPS1 	0x0002
#define	BIT_regBCR_BPS0 	0x0001
#define	BIT_regBCR_12MBPS 	(bitMKY36BCR_BPS1 | bitMKY36BCR_BPS0)
#define	BIT_regBCR_6MBPS 	(bitMKY36BCR_BPS1                   )
#define	BIT_regBCR_3MBPS 	(                   bitMKY36BCR_BPS0)

// MKY36_CCR   : 0x0590
//CCR
#define VAL_CCR10			0x4B4D       // 'M' = 0x4D, 'K' = 0x4B
#define VAL_CCR32			0x3359       // 'Y' = 0x59, '3' = 0x33
#define VAL_CCR54			0x2036       // '6' = 0x36, ' ' = 0x20




#endif//MKY_36_H//MKYデバイス初期化。
